pub enum BinaryError {
Message {
message: String,
},
UnexpectedEndOfInput,
InvalidBytes,
MissingOrInvalidFlag {
actual: u8,
expected: u8,
},
InvalidLength {
actual: usize,
expected: usize,
},
InvalidName {
actual: String,
expected: String,
},
UnexpectedType,
}Expand description
Errors that can be thrown by the Serializer or Deserializer
Variants
Message
A message only error
UnexpectedEndOfInput
unexpected end of input
InvalidBytes
an invalid set of bytes for the type expected
MissingOrInvalidFlag
missing or invalid flag
InvalidLength
inavlid length
InvalidName
invalid name
UnexpectedType
unexpected type