Versions of the Serde Binary Advanced Serializer and Deserializer optimized for use with streams that implement Read/Write
Structs
- Deserializer
- Deserializes binary data into Rust types
- Serializer
- A structure for serializing Rust values into binary.